@@ -16,9 +16,9 @@ from fastcore.test import *
 from fastcore.utils import *
 import torch
 import torch.nn as nn
-import psutil
 import scipy as sp
 import sklearn.metrics as skm
+from sklearn.metrics import make_scorer
 import gc
 import os
 from numbers import Integral
@@ -36,6 +36,11 @@ PATH = Path(os.getcwd())
 device = 'cuda' if torch.cuda.is_available() else 'cpu'
 cpus = defaults.cpus
 
+import sys
+IS_COLAB = 'google.colab' in sys.modules
+if IS_COLAB:
+    from numba import config
+    config.THREADING_LAYER = 'omp'
 
 def save_nb(verbose=False):
     display(Javascript('IPython.notebook.save_checkpoint();'))
@@ -69,7 +74,7 @@ def last_saved(max_elapsed=60):
         print('Incorrect conversion! 😔')
         output = 0
     print(f'Total time elapsed {elapsed:.0f} s')
-    print(strftime("%A %D %T %Z"))
+    print(strftime("%A %d/%m/%y %T %Z"))
     return output
 
 
@@ -106,7 +111,7 @@ class Timer:
         else: self.all_elapsed += elapsed
         pv(f'Elapsed time ({self.n:3}): {elapsed}', self.verbose)
         self.start_dt = datetime.now()
-        return elapsed
+        if not self.verbose: return elapsed
 
     def stop(self):
         end_dt = datetime.now()
@@ -116,12 +121,14 @@ class Timer:
         if self.all_elapsed == 0: self.all_elapsed = elapsed
         else: self.all_elapsed += elapsed
         total_elapsed = end_dt - self.start_dt0
-        if self.n > 1:
-            pv(f'Elapsed time ({self.n:3}): {elapsed}', self.verbose)
-            pv(f'Elapsed time (all): {self.all_elapsed}', self.verbose)
-        pv(f'Total time        : {total_elapsed}', self.verbose)
         delattr(self, "start_dt0")
         delattr(self, "start_dt")
-        return total_elapsed
+        if self.verbose:
+            if self.n > 1:
+                print(f'Elapsed time ({self.n:3}): {elapsed}')
+                print(f'Total time        : {self.all_elapsed}')
+            else: 
+                print(f'Total time        : {total_elapsed}')
+        else: return total_elapsed
 
 timer = Timer()
\ No newline at end of file
