@@ -19,14 +19,22 @@ from .RNN_FCN import *
 from .RNN_FCNPlus import *
 from .ROCKET import *
 from .MINIROCKET import *
+from .MINIROCKET_Pytorch import *
+from .MINIROCKETPlus_Pytorch import *
 from .TransformerModel import *
 from .TST import *
 from .TSTPlus import *
 from .XceptionTime import *
 from .XceptionTimePlus import *
 from .XCM import *
+from .XCMPlus import *
 from .XResNet1d import *
 from .XResNet1dPlus import *
 from fastai.vision.models.xresnet import *
 from .TabModel import *
-from .MultiInputNet import *
\ No newline at end of file
+from .TabTransformer import *
+from .TabFusionTransformer import *
+from .TSPerceiver import *
+from .MultiInputNet import *
+
+from .misc import *
\ No newline at end of file
